[Phpmyadmin-git] [SCM] phpMyAdmin branch, master, updated. RELEASE_3_3_2RC1-1346-g8a1e599

Marc Delisle lem9 at users.sourceforge.net
Wed Apr 7 23:01:21 CEST 2010


The branch, master has been updated
       via  8a1e59972566f9ee60bb5c0a1a96fe96898154f5 (commit)
      from  11688d3bc587f26fbc0e759950f65e065b26bf73 (commit)


- Log -----------------------------------------------------------------
commit 8a1e59972566f9ee60bb5c0a1a96fe96898154f5
Author: Marc Delisle <marc at infomarc.info>
Date:   Wed Apr 7 17:01:10 2010 -0400

    Mootools call for BLOB streaming converted to jQuery

-----------------------------------------------------------------------

Summary of changes:
 js/functions.js |    7 +++----
 1 files changed, 3 insertions(+), 4 deletions(-)

diff --git a/js/functions.js b/js/functions.js
index c7f8398..c2e8b63 100644
--- a/js/functions.js
+++ b/js/functions.js
@@ -1643,13 +1643,12 @@ function requestMIMETypeChange(db, table, reference, current_mime_type)
  */
 function changeMIMEType(db, table, reference, mime_type)
 {
     // specify url and parameters for mootools AJAx request
     var mime_chg_url = 'bs_change_mime_type.php';
     var params = { bs_db: db, bs_table: table, bs_reference: reference, bs_new_mime_type: mime_type };
 
-    // create AJAX object with above options and execute request
-    var chgRequest = new Request({ method: 'post', url: mime_chg_url, data: params, evalScripts: true });
-    chgRequest.send();
+    // jQuery POST
+    jQuery.post(mime_chg_url, params); 
 }
 
 /**
@@ -1643,13 +1643,12 @@ function requestMIMETypeChange(db, table, reference, current_mime_type)
 function changeMIMEType(db, table, reference, mime_type)
 {
-    // specify url and parameters for mootools AJAx request
+    // specify url and parameters for jQuery POST 
     var mime_chg_url = 'bs_change_mime_type.php';
     var params = { bs_db: db, bs_table: table, bs_reference: reference, bs_new_mime_type: mime_type };


hooks/post-receive
-- 
phpMyAdmin




More information about the Git mailing list